@@ -322,11 +322,6 @@ class Oct2Py(object):
         existing = glob.glob(spec)
         plot_offset = len(existing)
 
-        if not plot_height is None or not plot_width is None:
-            pre_call += """
-            close all;
-            """
-
         if plot_height is None and plot_width is None:
             plot_height = 420
             plot_width = 560
@@ -336,43 +331,22 @@ class Oct2Py(object):
             elif plot_width is None:
                 plot_width = 560
 
-        pre_call += """
-            set(0, 'DefaultFigurePosition', [300, 200, %(plot_width)s, %(plot_height)s]);
-            """ % locals()
-
-        if not plot_dir is None:
+        pre_call = "set(0, 'defaultfigureposition', [0 0 %(plot_width)s %(plot_height)s]);" % locals()
 
+        if plot_dir is not None:
+            plot_res = 150
             pre_call += """
                set(0, 'defaultfigurevisible', 'off');
-               close all;
+               graphics_toolkit('gnuplot');
                """
-
             plot_dir = plot_dir.replace("\\", "/")
 
             post_call += '''
-            figHandles_ = get(0, 'children');
-        for fig_ = 1:length(figHandles_)
-          f_ = figHandles_(fig_);
-          outfile_ = sprintf('%(plot_dir)s/%(plot_name)s%%03d.%(plot_format)s', f_ + %(plot_offset)s);
-          p_ = get(f_, 'position');
-          w_ = %(plot_width)s;
-          h_ = %(plot_height)s;
-          if p_(3) > %(plot_width)s
-                h_ = p_(4) * w_ / p_(3);
-          end
-          if p_(4) > %(plot_height)s
-                w_ = p_(3) * h_ / p_(4);
-          end
-          size_fmt_ = sprintf('-S%%d,%%d', w_, h_);
-          try
-            print(f_, outfile_, '-d%(plot_format)s', '-tight', size_fmt_);
-          end
-        end
-        close('all');
+            _make_figs("%(plot_dir)s", "%(plot_name)s", "%(plot_format)s", %(plot_offset)s, %(plot_res)s);
         ''' % locals()
         else:
             pre_call += """
-            "set(0, 'defaultfigurevisible', 'on');"
+            set(0, 'defaultfigurevisible', 'on');
             """
 
             post_call += """
@@ -834,8 +808,10 @@ class _Session(object):
 
         self.write(output + '\n')
 
+        # Run the pre-call
         self.expect(chr(2))
 
+        # Try and start the eval
         resp = self.expect('%s|error: |parse error:' % chr(2))
 
         if 'parse error:' in resp:
@@ -861,7 +837,7 @@ class _Session(object):
             elif '\x1b[C' in line or line.strip() == '>>':
                 line = ''
 
-            elif line.endswith('> '):
+            elif line.endswith('> ') and not line.endswith('>>> '):
                 self.interact(line)
 
             elif line.startswith(' ') and line.strip() == '^':
@@ -875,12 +851,17 @@ class _Session(object):
             if resp or line:
                 resp.append(line)
 
-        self.expect(chr(3))
+        # Run the post-call
+        post = self.expect('%s|error: |parse error:' % chr(3))
+        if (chr(3)) not in post:
+            raise Oct2PyError('Error in post_call: %s' % post)
 
         return '\n'.join(resp).rstrip()
 
     def _handle_first_run(self):
-        self.write('disp(available_graphics_toolkits());more off;disp(char(3))\n')
+        here = os.path.realpath(os.path.dirname(__file__))
+        here = here.replace(os.path.sep, '/')
+        self.write('disp(available_graphics_toolkits());more off;addpath(genpath("%s"));disp(char(3))\n' % here)
         resp = self.expect(chr(3))
         if not os.name == 'nt':
             try:
@@ -975,6 +956,12 @@ class _Session(object):
         except Exception as e:  # pragma: no cover
             self.logger.debug(e)
 
+        #Clean open pty terminals to avoid leaving to much of them opened
+        try:
+            os.close(self.wfid)
+        except Exception as e:  # pragma: no cover
+            self.logger.debug(e)
+
         self.reader.wants_abort = True
         self.proc = None
 
